@@ -3,7 +3,7 @@ use 5.010_000;
 use strict;
 use warnings;
 
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 our @EXPORT = qw(all_vars_ok test_vars vars_ok);
 
@@ -250,7 +250,7 @@ my $op_enteriter;
 my $op_entereval; # string eval
 my @op_svusers;
 BEGIN{
-    foreach my $op(qw(padsv padav padhv pp_match multideref)){
+    foreach my $op(qw(padsv padav padhv match multideref subst)){
         $padops[B::opnumber($op)]++;
     }
     # blead commit 93bad3fd55489cbd split aelemfast into two ops.
@@ -435,7 +435,7 @@ Test::Vars - Detects unused variables in perl modules
 
 =head1 VERSION
 
-This document describes Test::Vars version 0.011.
+This document describes Test::Vars version 0.012.
 
 =head1 SYNOPSIS
 
